'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const ApplicationHandler_1 = require("../application/ApplicationHandler");
const LoggerBroker_1 = require("../universal/LoggerBroker");
const GlobalConfigProcessor_1 = require("../universal/GlobalConfigProcessor");
const DaemonHandler_1 = require("../daemon/DaemonHandler");
const pandora_hub_1 = require("pandora-hub");
const globalConfigProcessor = GlobalConfigProcessor_1.GlobalConfigProcessor.getInstance();
/**
 * Class DebugApplicationLoader
 * For a profile.js application to debugging
 */
class DebugApplicationLoader {
    constructor(representation) {
        this.representation = representation;
    }
    /**
     * Start debug application
     * @return {Promise<void>}
     */
    async start() {
        const daemonRunning = await DaemonHandler_1.isDaemonRunning();
        // start a IPC-Hub when no daemon
        if (!daemonRunning) {
            const ipcHub = new pandora_hub_1.Hub();
            await ipcHub.start();
        }
        globalConfigProcessor.getAllProperties();
        globalConfigProcessor.mergeProperties({
            logger: {
                appLogger: {
                    stdoutLevel: 'ALL',
                    level: 'NONE'
                }
            }
        });
        process.env.PANDORA_DEV = 'true';
        process.env.NODE_ENV = process.env.NODE_ENV || 'local';
        const appName = this.representation.appName || 'debug';
        const options = Object.assign({}, this.representation, { appName });
        if (!this.master) {
            this.master = new ApplicationHandler_1.ApplicationHandler(options);
        }
        this.master.start().then(() => {
            console.log('Debug application start successful.');
        }).catch((err) => {
            LoggerBroker_1.consoleLogger.error(err);
        });
    }
}
exports.DebugApplicationLoader = DebugApplicationLoader;
//# sourceMappingURL=DebugApplicationLoader.js.map